<?php
/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Integration of Theme specific settings
 * (de) Integration von Theme spezifischen Einstellungen
 *
 * @copyright       Copyright 2006-2007, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.3.7
 * @lastmodified    2007-09-26
 */

/**
 * Allow configuration of theme settings, currently not available for PHP templates.
 * This feature becomes a core feature in Drupal 6.x for phptemplate based themes.
 *
 * Currently you must install Theme Settings API 5.x module for this functionality.
 * Look at http://drupal.org/project/themesettingsapi for the download.
 */
function phptemplate_settings($saved_settings) {

  // Set the default values for theme variables
  $defaults = array(
    'yaml_nav_primary' => 0,
    'yaml_nav_vertical' => 0,
    'yaml_layout_page_width_min' => '740px',
    'yaml_layout_page_width_max' => '80em',
    'yaml_layout_page_align' => 'center',
    'yaml_msie_hack_pngfix' => 0,
    'yaml_debug' => 0,
    'yaml_display_link_validation_xhtml' => 1,
    'yaml_display_link_validation_css' => 1,
    'yaml_display_link_license_yaml' => 1,
    'yaml_display_link_license_yamlfd' => 1,
  );

  // Merge the variables and their default values
  $variables = array_merge($defaults, $saved_settings);

  // Create the form using Form API
  $form['layout'] = array(
    '#type' => 'fieldset',
    '#title' => t('Layout'),
    '#collapsible' => true,
    '#collapsed' => false,
    '#description' => t('Leave the following defaults if you edit the basemod.ccs file directly. In this case there will be no extra inline settings added to the page by this config module.'),
  );
  $form['layout']['yaml_layout_page_width_min'] = array(
    '#type' => 'textfield',
    '#title' => t('Page min-width'),
    '#default_value' => $variables['yaml_layout_page_width_min'],
    '#description' => t('Defines the minium page width in <em>px</em> or <em>em</em>. Default: "740px".'),
    '#size' => '10'
  );
  $form['layout']['yaml_layout_page_width_max'] = array(
    '#type' => 'textfield',
    '#title' => t('Page max-width'),
    '#default_value' => $variables['yaml_layout_page_width_max'],
    '#description' => t('Defines the maximum page width in <em>px</em> or <em>em</em>. Default: "80em".'),
    '#size' => '10'
  );
  $form['layout']['yaml_layout_page_align'] = array(
    '#type' => 'select',
    '#title' => t('Page alignment'),
    '#default_value' => $variables['yaml_layout_page_align'],
    '#options' => array(
      'left' => t('left'),
      'center' => t('center'),
      'right' => t('right'),
    ),
    '#description' => t('Align the page to right, center or left. Default: "center".'),
  );

  $form['navigation'] = array(
    '#type' => 'fieldset',
    '#title' => t('Navigation'),
    '#collapsible' => true,
    '#collapsed' => false,
  );
  $form['navigation']['yaml_nav_primary'] = array(
    '#type' => 'select',
    '#title' => t('Menu containing primary links'),
    '#default_value' => $variables['yaml_nav_primary'],
    '#options' => array(
      '0' => 'nav_slidingdoor.css',
      '1' => 'nav_shinybuttons.css',
    ),
  );
  $form['navigation']['yaml_nav_vertical'] = array(
    '#type' => 'select',
    '#title' => t('Menu containing navigation links'),
    '#default_value' => $variables['yaml_nav_vertical'],
    '#options' => array(
      '0' => 'nav_vlist.css',
    ),
  );

  // Some Internet Explorer Specials
  $form['msie'] = array(
    '#type' => 'fieldset',
    '#title' => t('IE Special'),
    '#collapsible' => true,
    '#collapsed' => true,
  );
  $form['msie']['yaml_msie_hack_pngfix'] = array(
    '#type' => 'checkbox',
    '#title' => t('Internet Explorer PNG transparency'),
    '#default_value' => $variables['yaml_msie_hack_pngfix'],
    '#description' => t('Activates PNG transparency fix for filenames ending with "_trans.png" or images with CSS class "_trans" specified.'),
  );

  // Add miscellaneous settings
  $form['misc'] = array(
    '#type' => 'fieldset',
    '#title' => t('Miscellaneous'),
    '#collapsible' => true,
    '#collapsed' => true,
  );
  /*
  $form['misc']['yaml_debug'] = array(
    '#type' => 'checkbox',
    '#title' => t('Debug mode'),
    '#default_value' => $variables['yaml_debug'],
    '#description' => t("Activates YAML debug mode. Don't use this setting in production mode."),
    '#suffix' => '<hr />',
  ); */

  $form['misc']['yaml_display_link_validation_xhtml'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display W3C XHTML validation link'),
    '#default_value' => $variables['yaml_display_link_validation_xhtml'],
    '#description' => t('Shows a W3C XHTML validation link in the footer of every page.'),
  );
  $form['misc']['yaml_display_link_validation_css'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display W3C CSS validation link'),
    '#default_value' => $variables['yaml_display_link_validation_css'],
    '#description' => t('Shows a W3C CSS validation link in the footer of every page.'),
    '#suffix' => '<hr />',
  );

  $form['misc']['yaml_display_link_license_yaml'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display YAML Framework link'),
    '#default_value' => $variables['yaml_display_link_license_yaml'],
    '#description' => t('This back linking maybe only removed, if you possess a YAML Framework license.'),
    '#prefix' => '<p>'.t('<strong>License and terms of use:</strong><br />The YAML Framework and YAML for Drupal are licensed under a <a href="http://creativecommons.org/licenses/by-nc-sa/2.0/" target="_blank">Creative Commons</a> license. For more information see the following licenses and terms of use.</p><p>YAML Framework - <a href="http://www.yaml.de/artikel/hinweise/nutzung.html" target="_blank">http://www.yaml.de/artikel/hinweise/nutzung.html</a><br />YAML for Drupal - <a href="http://www.yaml-fuer-drupal.de/en/terms-of-use" target="_blank">http://www.yaml-fuer-drupal.de/en/terms-of-use</a>').'</p>',
  );
  $form['misc']['yaml_display_link_license_yamlfd'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display YAML for Drupal link'),
    '#default_value' => $variables['yaml_display_link_license_yamlfd'],
    '#description' => t('This back linking maybe only removed, if you have possess a YAML for Drupal license.'),
  );

  // Return the form
  return $form;
}
