<?php
/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Central template for global theme functions
 * (de) Zentrales Template für globale Theme-Funktionen
 *
 * @copyright       Copyright 2006-2007, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.3.7
 * @lastmodified    2007-09-26
 */

/**
 * This snippet changes primary links layout
 */
function phptemplate_links_primary($links) {
  $output = '';
  $count = 1;
  if (count($links)) {
    $output .= '<ul>';
    foreach ($links as $link) {
      $output .= '<li';
      if ((drupal_get_normal_path($link['href']) == $_GET['q']) || (drupal_is_front_page() && $link['href'] == '<front>') && $count == 1) {
        $output .= ' id="current"';
        $count = $count++;
      }
      $output .= '>'. l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']) .'</li>';
    }
    $output .= '</ul>';
  }
  return $output;
}

/**
 * This snippet changes seconday links layout
 */
function phptemplate_links_secondary($links, $delimiter = ' | ', $leftcab = '', $rightcab = '') {
  // Display the left cap of the 'button bar'
  $output  = '';
  $output .= $leftcab;
  $link_count = count($links);
  $current = 1;
  foreach ($links as $link) {
      // Print the link
      $output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']);
      // Only print the delimiter if not the last link
      if ($current < $link_count) {
        $output .= $delimiter;
      }
      $current++;
  }
  // Display the right cap of the 'button bar'
  $output .= $rightcab;
  return $output;
}

/**
 * This snippet changes default menu layout
 */
function phptemplate_menu_tree($pid = 1) {
  if ($tree = menu_tree($pid)) {
    $output .= "<ul class=\"menu\">";
    $output .= $tree;
    $output .= "</ul>";
    return $output;
  }
}
function phptemplate_menu_item($mid, $children = '', $leaf = TRUE) {
  return '<li class="'. ($leaf ? 'leaf' : ($children ? 'expanded' : 'collapsed')) .'">'. menu_item_link($mid) . $children ."</li>\n";
}

/**
* Catch the theme_profile_profile function, and redirect through the template api
*/
/*
function phptemplate_user_profile($user, $fields = array()) {
  // Pass to phptemplate, including translating the parameters to an associative array. The element names are the names that the variables
  // will be assigned within your template.
  // potential need for other code to extract field info
  return _phptemplate_callback('user-profile', array('user' => $user, 'fields' => $fields));
}
*/

/**
 * Customize the search form for breadcrumb position
 */
// jQuery Example
// drupal_add_js("$("#SearchText").focus(function() { if (this.value == "Search...") this.value = ""; });", 'inline', 'header', FALSE);
/*
function phptemplate_search_theme_form($form) {
  $output .= '<input type="text" maxlength="128" name="search_theme_form_keys" id="edit-search_theme_form_keys" value="'.t('Search...').'" title="'.t('Enter the terms you wish to search for.').'" class="form-text" onblur="if(this.value==\'\') this.value=\''.t('Search...').'\';" onfocus="if(this.value==\''.t('Search...').'\') this.value=\'\';" />';
  $output .= '<input type="submit" name="op" value="'.t('Search...').'" style="display: none;" />';
  $output .= '<input type="hidden" name="form_id" id="edit-search-theme-form" value="search_theme_form" />';
  $output .= '<input type="hidden" name="form_token" id="a-unique-id" value="'.drupal_get_token('search_theme_form').'" />';
  return $output;
}
*/

/**
 * This snippet will add module styles if module is installed and active.
 * TODO: Add CSS only if page requires the file
 */
function _yaml_add_css_modules($base_theme_directory = '') {

  // Add module styles if modules exists
  // The unique modules directory name should be used as CSS filename.
  if (module_exists('gallery')) {
    drupal_add_css($base_theme_directory .'/css/modules/gallery.css', 'theme');
  }
  if (module_exists('jrating')) {
    drupal_add_css($base_theme_directory .'/css/modules/jrating.css', 'theme');
  }
  if (module_exists('service_links')) {
    drupal_add_css($base_theme_directory .'/css/modules/service_links.css', 'theme');
  }
  if (module_exists('site_map') && arg(0) == 'sitemap') {
    drupal_add_css($base_theme_directory .'/css/modules/site_map.css', 'theme');
  }
  if (module_exists('project') && arg(0) == 'project') {
    drupal_add_css($base_theme_directory .'/css/modules/project.css', 'theme');
  }

  // Add non Drupal modules here.
  // To avoid naming conflicts an underscore should be added as prefix
  // to CSS filenames of modules not contributed on drupal.org.
  // if (foo == bar) {
  //   drupal_add_css($base_theme_directory .'/css/modules/_example.css', 'theme');
  // }

}

/**
 * Add backlinks required by license to footer.
 *
 * This back linking maybe only removed, if you possess
 * a YAML Framework and YAML for Drupal license.
 *
 * For more information read the "YAML" and "YAML for Drupal" license, please.
 *
 * Licenses:
 * YAML - http://www.yaml.de
 * YAML for Drupal - http://www.yaml-for-drupal.com
 */
function phptemplate_footer_message($output = '', $delimiter = ' | ', $leftcab = '', $rightcab = '') {

  $footer_items = array();

  // If you don't like the validation links, simply uncheck on theme settings page.
  if (theme_get_setting('yaml_display_link_validation_xhtml') !== 0) {
    $footer_items[] = t('<a href="http://validator.w3.org/check/referer" title="Validate XHTML" target="_blank">XHTML</a>');
  }

  if (theme_get_setting('yaml_display_link_validation_css') !== 0) {
    $footer_items[] = t('<a href="http://jigsaw.w3.org/css-validator/check/referer" title="Validate CSS" target="_blank">CSS</a>');
  }

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML-Framework Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you possess a YAML Framework license.
   * :: License conditions: http://www.yaml.de
   */
  if (theme_get_setting('yaml_display_link_license_yaml') !== 0) {
    $footer_items[] = t('<a href="http://www.yaml.de/" target="_blank">YAML</a> &copy; 2005-@year by <a href="http://www.highresolution.info/" target="_blank">Dirk Jesse</a>', array('@year' => date('Y')));
  }

  /**
   * GERMAN:
   * Diese Rückverlinkung darf nur entfernt werden,
   * wenn Sie eine YAML für Drupal Lizenz besitzen.
   * :: Lizenzbedingungen: http://www.yaml-fuer-drupal.de
   *
   * ENGLISH:
   * This back linking maybe only removed,
   * if you have possess a YAML for Drupal license.
   * :: License conditions: http://www.yaml-for-drupal.com
   */
  if (theme_get_setting('yaml_display_link_license_yamlfd') !== 0) {
    $footer_items[] = t('<a href="http://www.yaml-fuer-drupal.de/" title="YAML for Drupal Theme" target="_blank">YAML for Drupal</a> Theme &copy; 2006-@year by <a href="http://www.hass.de/" target="_blank">Alexander Haß</a>', array('@year' => date('Y')));
  }

  // Count items and add delimiters
  $footer_links_count = count($footer_items);
  $footer_links_current = 1;
  $footer_links_output = '';
  foreach ($footer_items as $footer_item) {
    $footer_links_output .= $footer_item;
    if ($footer_links_current < $footer_links_count) {
      $footer_links_output .= $delimiter;
    }
    $footer_links_current++;
  }

  // Build footer and links if exists
  $footer_output = '';
  if (trim($output) && $footer_links_count) {
    $footer_output = $output .'<br />'. $leftcab . $footer_links_output . $rightcab;
  }
  elseif (!trim($output) && $footer_links_count) {
    $footer_output = $leftcab . $footer_links_output . $rightcab;
  }
  else {
    $footer_output = $output;
  }

  // Return footer
  return $footer_output;
}

/**
 * We will detect if client is Internet Explorer. Then we are able to add
 * the XML prolog for XHTML Standard Compliance Mode for other browsers.
 *
 * Today IE is the only known software we need to workaround and therefor we
 * only detect IE browser and suppose all other browsers render correctly with
 * XML prolog.
 */
function _browser_xml_prolog_compliant() {
  $ua = $_SERVER['HTTP_USER_AGENT'];

  if (eregi('msie', $ua) && !eregi('opera', $ua)) {
    // This is not a Opera pose as IE
    $clientdata = explode(' ', stristr($ua, 'msie'));
    $client['version'] = $clientdata[1];

    if ($client['version'] >= 7) {
      // IE >= 7.0: http://blogs.msdn.com/ie/archive/2005/09/15/467901.aspx
      $xml_prolog_compliant = TRUE;
    }
    else {
      // IE <= 6.0
      $xml_prolog_compliant = FALSE;
    }
  }
  // all other browsers
  else {
    $xml_prolog_compliant = TRUE;
  }

  return $xml_prolog_compliant;
}
