<?php
/**
 * "Yet Another Multicolumn Layout" for Drupal
 *
 * (en) Central template for theme specific functions
 * (de) Zentrales Template für theme spezifische Funktionen
 *
 * @copyright       Copyright 2006-2007, Alexander Hass
 * @license         http://www.yaml-fuer-drupal.de/en/terms-of-use
 * @link            http://www.yaml-for-drupal.com
 * @package         yaml-for-drupal
 * @version         5.x-3.0.3.7
 * @lastmodified    2007-09-26
 */

/**
 * Include the central template.inc with global theme functions
 */
include_once(realpath(dirname(__FILE__) .'/template.inc'));

/**
 * Alter some Drupal variables required by Theme
 */
function _phptemplate_variables($hook, $vars = array()) {
  switch ($hook) {
    case 'page':
      global $user;

      // Load the XML prolog for standard compliant browsers if caching is inactive.
      // The function page_set_cache() does not cache pages if $user->uid has a value.
      // Additional the XML prolog can only added to YAML for Drupal if a user is
      // logged into Drupal (caching inactive) or caching is globaly disabled on the site.
      if ((_browser_xml_prolog_compliant() && $user->uid) || (_browser_xml_prolog_compliant() && !(variable_get('cache', 0)))) {
        $vars['xml_prolog'] = '<?xml version="1.0" encoding="utf-8"?>' . "\n";
      }

      // Load region content assigned via drupal_set_content().
      if (module_exists('fontsize')) {
        foreach (array('fontsize_init', 'fontsize_links') as $region) {
          $vars[$region] = drupal_get_content($region);
        }
      }

      // Add YAML Theme styles
      $vars['css'] = _yaml_add_css($vars);
      $vars['styles'] = _yaml_add_styles($vars);

      break;
  }

  // node_style module is installed and active
  if (module_exists('node_style')) {
    return node_style_return_vars($hook, $vars);
  }
  else {
    return $vars;
  }

}

/**
 * Theme Regions
 */
function yaml_regions() {
  return array(
    'left' => t('left sidebar'),
    'content' => t('content'),
    'header' => t('header'),
    'footer' => t('footer'),
  );
}

/**
 * Theme CSS files
 *
 * Workaround for CSS aggregate and compress feature in Drupal 5.x
 */
function _yaml_add_css($vars = array()) {

  $base_theme_directory = $vars['directory'];

  // Add core and layout specific styles
  drupal_add_css($base_theme_directory .'/yaml/core/base.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod_2col_left_13.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/screen/basemod_drupal.css', 'theme');

  // Add horizontal navigations
  $yaml_nav_primary = theme_get_setting('yaml_nav_primary');
  if ($yaml_nav_primary == 1) {
    drupal_add_css($base_theme_directory .'/css/navigation/nav_shinybuttons.css', 'theme');
  }
  else {
    drupal_add_css($base_theme_directory .'/css/navigation/nav_slidingdoor.css', 'theme');
  }

  // Add vertical navigations
  $yaml_nav_vertical = theme_get_setting('yaml_nav_vertical');
  if ($yaml_nav_vertical == 1) {
    // There are currently no additional navigations available, add here if you create your own.
  }
  else {
    drupal_add_css($base_theme_directory .'/css/navigation/nav_vlist_drupal.css', 'theme');
  }

  // Content CSS files
  drupal_add_css($base_theme_directory .'/css/screen/content.css', 'theme');

  // Add custom module styles
  _yaml_add_css_modules($base_theme_directory);

  // Add print CSS files
  drupal_add_css($base_theme_directory .'/yaml/core/print_base.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/print/print_003.css', 'theme');
  drupal_add_css($base_theme_directory .'/css/print/print.css', 'theme');

  // Add debug CSS files
  if (theme_get_setting('yaml_debug') == 1) {
    drupal_add_css($base_theme_directory .'/yaml/debug/debug.css', 'theme', 'all', FALSE);
  }

  // Remove the style.css added as first array item and move it to the end
  // of the styles array. This allows to use themes style.css and keep
  // the required CSS cascading order intact for CSS overriding.
  $css = drupal_add_css();
  if (isset($css['all']['theme'][$vars['directory'] .'/style.css'])) {
    unset($css['all']['theme'][$vars['directory'] .'/style.css']);
    $css['all']['theme'][$vars['directory'] .'/style.css'] = TRUE;
  }

  // Return CSS array
  return $css;
}

function _yaml_add_styles($vars = array()) {

  $base_theme_directory = $vars['directory'];
  $output = drupal_get_css($vars['css']);

  // The styles array is complete, get the styled css and append the
  // IE Hacks. Additional this allows to dynamically add packed or other iehacks.
  $output .= "<!--[if lte IE 7]>\n";
  $output .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/yaml/core/iehacks'. (variable_get('preprocess_css', FALSE) ? '.pack' : '') .'.css";</style>' . "\n";
  $output .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/css/patches/patch_nav_vlist_drupal.css";</style>' . "\n";
  $output .= '<style type="text/css" media="all">@import "'. base_path() . $base_theme_directory .'/css/patches/patch_2col_left_13.css";</style>' . "\n";
  $output .= "<![endif]-->\n";

  // Add IE6 CSS hacks
  if (theme_get_setting('yaml_msie_hack_pngfix') == 1) {
    $output .= "<!--[if lte IE 6]>\n";
    $output .= '<style type="text/css">img, .pngtrans { behavior: url('. base_path() . $base_theme_directory .'/images/pngfix/iepngfix.htc) }</style>' . "\n";
    $output .= "<![endif]-->\n";
  }

  // Page settings
  $yaml_layout_page_width_min = theme_get_setting('yaml_layout_page_width_min');
  $yaml_layout_page_width_max = theme_get_setting('yaml_layout_page_width_max');
  $yaml_layout_page_align = theme_get_setting('yaml_layout_page_align');
  if ($yaml_layout_page_align == 'left') {
    $output .= '<style type="text/css">#page_margins { margin-right: auto; margin-left: 0; min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
  }
  elseif ($yaml_layout_page_align == 'right') {
    $output .= '<style type="text/css">#page_margins { margin-left: auto; margin-right: 0; min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
  }
  elseif ($yaml_layout_page_align == 'center' && ($yaml_layout_page_width_min != '740px' || $yaml_layout_page_width_max != '80em')) {
    $output .= '<style type="text/css">#page_margins { min-width: '. check_plain($yaml_layout_page_width_min) .'; max-width: '. check_plain($yaml_layout_page_width_max) .' }</style>' . "\n";
  }

  // Return themed styles
  return $output;
}
